#!/bin/sh
# RSAS INSTALL SCRIPT FOR FREEBSD
# You must run this as root.
# This script is safe to run over an existing RSAS installation and will not overwrite your
# config file.

if ! [ $(id -u) = 0 ]; then
    echo "Please run this install script as root."
    exit
fi

# Create rsas user and group
echo "Creating rsas user and group"
pwd_mkdb /etc/master.passwd   # Make sure DB is synced first to avoid possible useradd error
pw groupadd rsas
pw useradd rsas -d /usr/local/www/rsas/webroot -g rsas -w no -L rsas -s /usr/sbin/nologin

echo "Creating directories..."
mkdir -p /usr/local/www/rsas
mkdir -p /usr/local/www/rsas/webroot
mkdir -p /var/log/rsas

echo "Copying files..."
DPERM='-m 0664 -g rsas -o rsas'
mkdir -p /usr/local/www/rsas/templates
mkdir -p /usr/local/www/rsas/webroot/images
mkdir -p /usr/local/www/rsas/webroot/css
mkdir -p /usr/local/etc/rsas

cp -R templates/* /usr/local/www/rsas/templates
cp -R images/* /usr/local/www/rsas/webroot/images
cp -R css/* /usr/local/www/rsas/webroot/css
cp -R etc/rsas/* /usr/local/etc/rsas
cp -R rc.d/* /usr/local/etc/rc.d
install -m 0755 rsas /usr/local/bin/

echo "Tightening permissions..."
chown -R rsas:rsas /usr/local/www/rsas /var/log/rsas /usr/local/etc/rsas
chmod -R u=rw,g=rw,o=r,ugo+X /usr/local/www/rsas /var/log/rsas
chmod -R u=rw,g=rw,o=,ugo+X /usr/local/etc/rsas
chmod -R ug=rw,o=,ug+X /usr/local/etc/rsas/rsas.xml.example_simple
echo "*** Installation Complete ***"
echo "Next step: You must manually create your /etc/rsas/rsas.xml configuration file."
echo "You can copy and use /etc/rsas/rsas.xml.example-simple as a starting point."

